DataFile class

Available extensions

Constructors

DataFile()
DataFile.fromMap(Map<String, dynamic> value)
factory

Properties

createdAt DateTime?
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
name String
no setter
parent String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime?
no setter

Methods

getBytes() Future<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
path() String

Available on DataFile, provided by the DataFileExtensionLocal extension

pathFile() String

Available on DataFile, provided by the DataFileExtensionLocal extension

save() Future<String>
saveBytes(Uint8List value) Future<bool>
toMap() Map<String, dynamic>

Available on DataFile, provided by the DataFileExtensionLocal extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(String id, {String? parent, String? name, int? seq}) DataFile