DataLocal class

Available extensions

Constructors

DataLocal(String stateName, {dynamic onRefresh()?, bool debugMode = false})

Properties

count int
no setter
hashCode int
The hash code for this object.
no setterinherited
isInit bool
no setter
isLoading bool
no setter
onRefresh ↔ dynamic Function()?
getter/setter pair
raw Map<String, DataItem>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
no setter
stateName String
no setter

Methods

dispose() → void
execute(List selects, {List<DataFilter>? filters, List<DataSort>? sorts, List? groups, int? limit}) Future<List<DataItemRow>>

Available on DataLocal, provided by the DataLocalExtensionQuery extension

Find More specific query Data with this function
find({List<DataFilter>? filters, List<DataSort>? sorts, DataSearch? search, DataPaginate? paginate}) Future<DataQuery>
Find More Efective Data with this function
get(String id) Future<DataItem?>
insertMany(List<Map<String, dynamic>> values) Future<void>
insertOne(Map<String, dynamic> value, {String? id}) Future<DataItem>
Insert and save DataItem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reboot() Future<void>
Start from initialize, save state will not deleted
refresh() → void
Refresh data, launch if onRefresh is include
removeMany(List<String> ids) Future<void>
removeOne(String id) Future<void>
Deletion DataItem
toString() String
A string representation of this object.
inherited
updateOne(String id, {required Map<String, dynamic> value}) Future<DataItem>
Update to save DataItem

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(String stateName, {dynamic onRefresh()?, bool? debugMode}) Future<DataLocal>
Used for the first time initialize DataLocal