DataLocalErrorCode enum

Stable categories for errors callers may handle programmatically.

Inheritance
Available extensions

Values

closed → const DataLocalErrorCode
conflict → const DataLocalErrorCode
corruption → const DataLocalErrorCode
encryption → const DataLocalErrorCode
initialization → const DataLocalErrorCode
migration → const DataLocalErrorCode
notFound → const DataLocalErrorCode
read → const DataLocalErrorCode
serialization → const DataLocalErrorCode
unsupported → const DataLocalErrorCode
validation → const DataLocalErrorCode
write → const DataLocalErrorCode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DataLocalErrorCode>
A constant List of the values in this enum, in order of their declaration.