DataLocalInitializationException class final

Inheritance

Constructors

DataLocalInitializationException(String message, {Map<String, Object?> context = const <String, Object?>{}, Object? cause, StackTrace? causeStackTrace})
const

Properties

cause Object?
finalinherited
causeStackTrace StackTrace?
finalinherited
code DataLocalErrorCode
finalinherited
context Map<String, Object?>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited