DataLocalStorage class abstract interface

Persistence boundary implemented by every DataLocal storage backend.

Implementers

Properties

capabilities DataLocalStorageCapabilities
no setter
hashCode int
The hash code for this object.
no setterinherited
isOpen bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCollection(String collection) Future<void>
clearJournal() Future<void>
Removes the recovery journal after a commit is fully durable.
close() Future<void>
delete(String collection, String id) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(DataLocalStorageContext context) Future<void>
read(String collection, String id) Future<DataLocalStoredRecord?>
readCollection(String collection) Future<List<DataLocalStoredRecord>>
readJournal() Future<Uint8List?>
Returns the database-level recovery journal, when a commit was interrupted.
toString() String
A string representation of this object.
inherited
write(DataLocalStoredRecord record) Future<void>
writeJournal(Uint8List payload) Future<void>
Atomically replaces the database-level recovery journal blob.

Operators

operator ==(Object other) bool
The equality operator.
inherited