DataLocalFilter class final
An immutable field predicate used by DataLocalQuery.
Constructors
- DataLocalFilter({required DataLocalFieldPath path, required DataLocalFilterOperator operator, required Object? value})
-
Creates a predicate for
path.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- operator → DataLocalFilterOperator
-
Comparison performed against value.
final
- path → DataLocalFieldPath
-
Field path evaluated by this predicate.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → Object?
-
Operand supplied to operator.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited